@@ -1,6 +1,8 @@
 .prompt_user_for_change_description <-
-  function(interact = getOption("DataPackageR_interact",
-                                interactive())) {
+  function(interact = getOption(
+               "DataPackageR_interact",
+               interactive()
+             )) {
     cat(crayon::cyan("Enter a text description of the changes for the NEWS file.\n")) # nolint
     change_description <-
       ifelse(
@@ -12,8 +14,10 @@
   }
 
 .update_news_md <- function(version = "Version Not Provided",
-                            interact = getOption("DataPackageR_interact",
-                                                 interactive())) {
+                            interact = getOption(
+                              "DataPackageR_interact",
+                              interactive()
+                            )) {
   news_file <- .newsfile()
   change_description <-
     .prompt_user_for_change_description(interact = interact)
@@ -25,14 +29,17 @@
     sep = "\n"
   )
   writeLines("=======================",
-             con = news_con,
-             sep = "\n")
+    con = news_con,
+    sep = "\n"
+  )
   writeLines(c(change_description, ""),
-             con = news_con,
-             sep = "\n")
+    con = news_con,
+    sep = "\n"
+  )
   writeLines(news_file_data,
-             con = news_con,
-             sep = "\n")
+    con = news_con,
+    sep = "\n"
+  )
   flush(news_con)
   close(news_con)
 }
