@@ -42,12 +42,12 @@ datapackage_skeleton <-
     if (is.null(name)) {
       stop("Must supply a package name", call. = FALSE)
     }
-    if (length(r_object_names) == 0) {
-      stop("You must specify r_object_names", call. = FALSE)
-    }
-    if (length(code_files) == 0) {
-      stop("You must specify code_files", call. = FALSE)
-    }
+    #if (length(r_object_names) == 0) {
+    #  stop("You must specify r_object_names", call. = FALSE)
+    #}
+    #if (length(code_files) == 0) {
+    #  stop("You must specify code_files", call. = FALSE)
+    #}
     if (force) {
       unlink(file.path(path, name), recursive = TRUE, force = TRUE)
     }
@@ -167,6 +167,7 @@ datapackage_skeleton <-
 #' @aliases datapackage_skeleton
 #' @export
 #' @examples
+#' if(rmarkdown::pandoc_available()){
 #' f <- tempdir()
 #' f <- file.path(f,"foo.Rmd")
 #' con <- file(f)
@@ -178,6 +179,7 @@ datapackage_skeleton <-
 #'    force = TRUE,
 #'    r_object_names = "tbl",
 #'    code_files = f)
+#'    }
 datapackage.skeleton <- function(name = NULL,
                                  list = character(),
                                  environment = .GlobalEnv,
