@@ -1,5 +1,8 @@
 library(testthat)
 library(DataPackageR)
 options("DataPackageR_interact" = FALSE)
-test_check("DataPackageR")
+# Test only if pandoc is available.
+if (rmarkdown::pandoc_available()) {
+  test_check("DataPackageR")
+}
 options("DataPackageR_interact" = interactive())
